import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_applicationautoscaling._jsii
import aws_cdk.aws_autoscaling._jsii
import aws_cdk.aws_autoscaling_hooktargets._jsii
import aws_cdk.aws_certificatemanager._jsii
import aws_cdk.aws_cloudwatch._jsii
import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_ecr._jsii
import aws_cdk.aws_ecr_assets._jsii
import aws_cdk.aws_elasticloadbalancing._jsii
import aws_cdk.aws_elasticloadbalancingv2._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_kms._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_logs._jsii
import aws_cdk.aws_route53._jsii
import aws_cdk.aws_route53_targets._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_s3_assets._jsii
import aws_cdk.aws_secretsmanager._jsii
import aws_cdk.aws_servicediscovery._jsii
import aws_cdk.aws_sns._jsii
import aws_cdk.aws_sqs._jsii
import aws_cdk.aws_ssm._jsii
import aws_cdk.core._jsii
import aws_cdk.cx_api._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-ecs", "1.155.0", __name__[0:-6], "aws-ecs@1.155.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
